package com.ruoyi.web.controller.system;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.TDeviceList;
import com.ruoyi.system.service.ITDeviceListService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 设备列Controller
 * 
 * @author zhengjie
 * @date 2023-08-30
 */
@RestController
@RequestMapping("/system/device")
public class TDeviceListController extends BaseController
{
    @Autowired
    private ITDeviceListService tDeviceListService;

    /**
     * 查询设备列列表
     */
    @PreAuthorize("@ss.hasPermi('system:device:list')")
    @GetMapping("/list")
    public TableDataInfo list(TDeviceList tDeviceList)
    {
        startPage();
        List<TDeviceList> list = tDeviceListService.selectTDeviceListList(tDeviceList);
        return getDataTable(list);
    }

    /**
     * 导出设备列列表
     */
    @PreAuthorize("@ss.hasPermi('system:device:export')")
    @Log(title = "设备列", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, TDeviceList tDeviceList)
    {
        List<TDeviceList> list = tDeviceListService.selectTDeviceListList(tDeviceList);
        ExcelUtil<TDeviceList> util = new ExcelUtil<TDeviceList>(TDeviceList.class);
        util.exportExcel(response, list, "设备列数据");
    }

    /**
     * 获取设备列详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:device:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Integer id)
    {
        return success(tDeviceListService.selectTDeviceListById(id));
    }

    /**
     * 新增设备列
     */
    @PreAuthorize("@ss.hasPermi('system:device:add')")
    @Log(title = "设备列", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TDeviceList tDeviceList)
    {
        return toAjax(tDeviceListService.insertTDeviceList(tDeviceList));
    }

    /**
     * 修改设备列
     */
    @PreAuthorize("@ss.hasPermi('system:device:edit')")
    @Log(title = "设备列", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TDeviceList tDeviceList)
    {
        return toAjax(tDeviceListService.updateTDeviceList(tDeviceList));
    }

    /**
     * 删除设备列
     */
    @PreAuthorize("@ss.hasPermi('system:device:remove')")
    @Log(title = "设备列", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Integer[] ids)
    {
        return toAjax(tDeviceListService.deleteTDeviceListByIds(ids));
    }
}
